==> dnv_bladed_models-0.4.0.tar.gz: dnv_bladed_models-0.4.0/src/dnv_bladed_models/preset_wind_mean_speed_transient.py <==
# coding: utf-8

from __future__ import annotations

from datetime import date, datetime  # noqa: F401
from enum import Enum, IntEnum

import re  # noqa: F401
from typing import Any, Dict, List, Optional, Type, Union, Callable  # noqa: F401
from pathlib import Path
from typing import TypeVar
Model = TypeVar('Model', bound='BaseModel')
StrBytes = Union[str, bytes]

from pydantic import AnyUrl, BaseModel, EmailStr, Field, validator, root_validator, Extra,PrivateAttr  # noqa: F401
from pydantic import ValidationError
from pydantic.error_wrappers import ErrorWrapper
from pydantic.utils import ROOT_KEY
from json import encoder

from dnv_bladed_models.wind_mean_speed_variation import WindMeanSpeedVariation



class PresetWindMeanSpeedTransient_VariationShapeEnum(str, Enum):
    FULL = "FULL"
    HALF = "HALF"
    IEC_2 = "IEC-2"

from .schema_helper import SchemaHelper 
from .models_impl import *
from .common_base_model import CommonBaseModel

class PresetWindMeanSpeedTransient(WindMeanSpeedVariation, MeanSpeedVariationType='PresetTransient'):
    r"""
    A preset transient in the mean wind speed.
    
    Not supported yet.
    
    Attributes:
    ----------
    MeanSpeedVariationType : str, default='PresetTransient', Not supported yet
        Defines the specific type of MeanSpeedVariation model in use.  For a `PresetTransient` object, this must always be set to a value of `PresetTransient`.

    MeanSpeedAtStart : float, Not supported yet
        The mean wind speed at the start of the simulation up to the beginning of the transient.  For a full cycle this will also be the value after the transient has completed.

    AmplitudeOfVariation : float, Not supported yet
        The maximum amplitude of the variation.

    StartTime : float, Not supported yet
        The time into the simulation at which to start the transient (excluding the lead-in time).

    DurationOfVariation : float, Not supported yet
        The time taken to complete the transient, whether half-cycle or full-cycle.

    VariationShape : PresetWindMeanSpeedTransient_VariationShapeEnum, Not supported yet
        The shape of the transient.  This can either be a half-cycle (where the wind speed remains at the initial wind speed plus the amplitude after the transient has been completed) or a full-cycle (where the wind speed returns to its original value).

    Notes:
    -----This model is not supported yet by the Bladed calculation engine.
    """
    _relative_schema_path: str = PrivateAttr('TimeDomainSimulation/Environment/Wind/WindMeanSpeedVariation/PresetWindMeanSpeedTransient.json')
    
    MeanSpeedVariationType: Optional[str] = Field(alias="MeanSpeedVariationType", default='PresetTransient') # Not supported yet
    MeanSpeedAtStart: Optional[float] = Field(alias="MeanSpeedAtStart", default=None) # Not supported yet
    AmplitudeOfVariation: Optional[float] = Field(alias="AmplitudeOfVariation", default=None) # Not supported yet
    StartTime: Optional[float] = Field(alias="StartTime", default=None) # Not supported yet
    DurationOfVariation: Optional[float] = Field(alias="DurationOfVariation", default=None) # Not supported yet
    VariationShape: Optional[PresetWindMeanSpeedTransient_VariationShapeEnum] = Field(alias="VariationShape", default=None) # Not supported yet

    class Config:
        extra = Extra.forbid
        validate_assignment = True
        allow_population_by_field_name = True
        pass



    def to_json(self, indent: Optional[int] = 2, **json_kwargs: Any) -> str:
        r"""
        Generates a JSON string representation of the model.

        Parameters
        ----------
        indent : int
            The whitespace indentation to use for formatting, as per json.dumps().

        Examples
        --------
        >>> model.to_json()
        Renders the full JSON representation of the model object.
        """

        json_kwargs['by_alias'] = True
        json_kwargs['exclude_unset'] = True
        json_kwargs['exclude_none'] = True
        if self.Schema is None:
            self.Schema = SchemaHelper.construct_schema_url(self._relative_schema_path)
        
        return super().json(indent=indent, **json_kwargs)


    @classmethod
    def from_file(cls: Type['Model'], path: Union[str, Path]) -> 'Model':
        r"""
        Loads a model from a given file path.

        Parameters
        ----------
        path : string
            The file path to the model.

        Returns
        -------
        PresetWindMeanSpeedTransient
            The model object.

        Raises
        ------
        ValueError, ValidationError
            If the JSON document does not correctly describe the model according to the model schema.

        Examples
        --------
        >>> model = PresetWindMeanSpeedTransient.from_file('/path/to/file')
        """
        
        return super().parse_file(path=path)


    @classmethod
    def from_json(cls: Type['Model'], b: StrBytes) -> 'Model':
        r"""
        Creates a model object from a JSON string.

        Parameters
        ----------
        b: StrBytes
            The JSON string describing the model.

        Returns
        -------
        PresetWindMeanSpeedTransient
            The model object.

        Raises
        ------
        ValueError, ValidationError
            If the JSON document does not correctly describe the model according to the model schema.

        Examples
        --------
        >>> model = PresetWindMeanSpeedTransient.from_json('{ ... }')
        """

        return super().parse_raw(
            b=b,
            content_type='application/json')
        

    @classmethod
    def from_dict(cls: Type['Model'], obj: Any) -> 'Model':
        r"""
        Creates a model object from a dict.
        
        Parameters
        ----------
        obj : Any
            The dictionary object describing the model.

        Returns
        -------
        PresetWindMeanSpeedTransient
            The model object.

        Raises
        ------
        ValueError, ValidationError
            If the JSON document does not correctly describe the model according to the model schema.
        """
        
        return super().parse_obj(obj=obj)


    def to_file(self, path: Union[str, Path]):
        r"""
        Writes the model as a JSON document to a file with UTF8 encoding.

        Parameters
        ----------                
        path : string
            The file path to which the model will be written.

        Examples
        --------
        >>> model.to_file('/path/to/file')
        """

        with open(file=path, mode='w', encoding="utf8") as output_file:
            output_file.write(self.to_json())


PresetWindMeanSpeedTransient.update_forward_refs()

==> dnv_bladed_models-0.4.1.tar.gz: dnv_bladed_models-0.4.1/src/dnv_bladed_models/preset_wind_mean_speed_transient.py <==
# coding: utf-8

from __future__ import annotations

from datetime import date, datetime  # noqa: F401
from enum import Enum, IntEnum

import re  # noqa: F401
from typing import Any, Dict, List, Optional, Type, Union, Callable  # noqa: F401
from pathlib import Path
from typing import TypeVar
Model = TypeVar('Model', bound='BaseModel')
StrBytes = Union[str, bytes]

from pydantic import AnyUrl, BaseModel, EmailStr, Field, validator, root_validator, Extra,PrivateAttr  # noqa: F401
from pydantic import ValidationError
from pydantic.error_wrappers import ErrorWrapper
from pydantic.utils import ROOT_KEY
from json import encoder

from dnv_bladed_models.wind_mean_speed_variation import WindMeanSpeedVariation



class PresetWindMeanSpeedTransient_VariationShapeEnum(str, Enum):
    FULL = "FULL"
    HALF = "HALF"
    IEC_2 = "IEC-2"

from .schema_helper import SchemaHelper 
from .models_impl import *
from .common_base_model import CommonBaseModel

class PresetWindMeanSpeedTransient(WindMeanSpeedVariation, MeanSpeedVariationType='PresetTransient'):
    r"""
    A preset transient in the mean wind speed.
    
    Not supported yet.
    
    Attributes:
    ----------
    MeanSpeedVariationType : str, default='PresetTransient', Not supported yet
        Defines the specific type of MeanSpeedVariation model in use.  For a `PresetTransient` object, this must always be set to a value of `PresetTransient`.

    MeanSpeedAtStart : float, Not supported yet
        The mean wind speed at the start of the simulation up to the beginning of the transient.  For a full cycle this will also be the value after the transient has completed.

    AmplitudeOfVariation : float, Not supported yet
        The maximum amplitude of the variation.

    StartTime : float, Not supported yet
        The time into the simulation at which to start the transient (excluding the lead-in time).

    DurationOfVariation : float, Not supported yet
        The time taken to complete the transient, whether half-cycle or full-cycle.

    VariationShape : PresetWindMeanSpeedTransient_VariationShapeEnum, Not supported yet
        The shape of the transient.  This can either be a half-cycle (where the wind speed remains at the initial wind speed plus the amplitude after the transient has been completed) or a full-cycle (where the wind speed returns to its original value).

    Notes:
    -----This model is not supported yet by the Bladed calculation engine.
    """
    _relative_schema_path: str = PrivateAttr('TimeDomainSimulation/Environment/Wind/WindMeanSpeedVariation/PresetWindMeanSpeedTransient.json')
    
    MeanSpeedVariationType: Optional[str] = Field(alias="MeanSpeedVariationType", default='PresetTransient') # Not supported yet
    MeanSpeedAtStart: Optional[float] = Field(alias="MeanSpeedAtStart", default=None) # Not supported yet
    AmplitudeOfVariation: Optional[float] = Field(alias="AmplitudeOfVariation", default=None) # Not supported yet
    StartTime: Optional[float] = Field(alias="StartTime", default=None) # Not supported yet
    DurationOfVariation: Optional[float] = Field(alias="DurationOfVariation", default=None) # Not supported yet
    VariationShape: Optional[PresetWindMeanSpeedTransient_VariationShapeEnum] = Field(alias="VariationShape", default=None) # Not supported yet

    class Config:
        extra = Extra.forbid
        validate_assignment = True
        allow_population_by_field_name = True
        pass



    def to_json(self, indent: Optional[int] = 2, **json_kwargs: Any) -> str:
        r"""
        Generates a JSON string representation of the model.

        Parameters
        ----------
        indent : int
            The whitespace indentation to use for formatting, as per json.dumps().

        Examples
        --------
        >>> model.to_json()
        Renders the full JSON representation of the model object.
        """

        json_kwargs['by_alias'] = True
        json_kwargs['exclude_unset'] = False
        json_kwargs['exclude_none'] = True
        if self.Schema is None:
            self.Schema = SchemaHelper.construct_schema_url(self._relative_schema_path)
        
        return super().json(indent=indent, **json_kwargs)


    @classmethod
    def from_file(cls: Type['Model'], path: Union[str, Path]) -> 'Model':
        r"""
        Loads a model from a given file path.

        Parameters
        ----------
        path : string
            The file path to the model.

        Returns
        -------
        PresetWindMeanSpeedTransient
            The model object.

        Raises
        ------
        ValueError, ValidationError
            If the JSON document does not correctly describe the model according to the model schema.

        Examples
        --------
        >>> model = PresetWindMeanSpeedTransient.from_file('/path/to/file')
        """
        
        return super().parse_file(path=path)


    @classmethod
    def from_json(cls: Type['Model'], b: StrBytes) -> 'Model':
        r"""
        Creates a model object from a JSON string.

        Parameters
        ----------
        b: StrBytes
            The JSON string describing the model.

        Returns
        -------
        PresetWindMeanSpeedTransient
            The model object.

        Raises
        ------
        ValueError, ValidationError
            If the JSON document does not correctly describe the model according to the model schema.

        Examples
        --------
        >>> model = PresetWindMeanSpeedTransient.from_json('{ ... }')
        """

        return super().parse_raw(
            b=b,
            content_type='application/json')
        

    @classmethod
    def from_dict(cls: Type['Model'], obj: Any) -> 'Model':
        r"""
        Creates a model object from a dict.
        
        Parameters
        ----------
        obj : Any
            The dictionary object describing the model.

        Returns
        -------
        PresetWindMeanSpeedTransient
            The model object.

        Raises
        ------
        ValueError, ValidationError
            If the JSON document does not correctly describe the model according to the model schema.
        """
        
        return super().parse_obj(obj=obj)


    def to_file(self, path: Union[str, Path]):
        r"""
        Writes the model as a JSON document to a file with UTF8 encoding.

        Parameters
        ----------                
        path : string
            The file path to which the model will be written.

        Examples
        --------
        >>> model.to_file('/path/to/file')
        """

        with open(file=path, mode='w', encoding="utf8") as output_file:
            output_file.write(self.to_json())


PresetWindMeanSpeedTransient.update_forward_refs()
